==> easy-antd-modal-1.0.0.tgz: package/lib/modal/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/modal/index.tsx
var modal_exports = {};
__export(modal_exports, {
  default: () => modal_default
});
module.exports = __toCommonJS(modal_exports);
var import_antd = require("antd");
var React = __toESM(require("react"));
var import_hooks = require("../hooks");
var Modal = (props) => {
  const { onOk, onCancel, ...restProps } = props;
  const [visible, { close }, { trigger, content }] = (0, import_hooks.useModalEnhanced)(props);
  const handleModalOk = (event) => {
    onOk == null ? void 0 : onOk(event);
    close();
  };
  const handleModalCancel = (event) => {
    onCancel == null ? void 0 : onCancel(event);
    close();
  };
  return /* @__PURE__ */ React.createElement(React.Fragment, null, trigger, /* @__PURE__ */ React.createElement(import_antd.Modal, { open: visible, onOk: handleModalOk, onCancel: handleModalCancel, ...restProps }, content));
};
var modal_default = Modal;

==> easy-antd-modal-1.4.0.tgz: package/lib/modal/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/modal/index.tsx
var modal_exports = {};
__export(modal_exports, {
  default: () => modal_default
});
module.exports = __toCommonJS(modal_exports);
var import_antd = require("antd");
var import_hooks = require("../hooks");
var Modal = (props) => {
  const [visible, { close }, { trigger, content }, restProps] = (0, import_hooks.useModalEnhanced)(props);
  const handleModalOk = (event) => {
    var _a;
    (_a = props.onOk) == null ? void 0 : _a.call(props, event);
    close();
  };
  const handleModalCancel = (event) => {
    var _a;
    (_a = props.onCancel) == null ? void 0 : _a.call(props, event);
    close();
  };
  return /* @__PURE__ */ React.createElement(React.Fragment, null, trigger, /* @__PURE__ */ React.createElement(import_antd.Modal, { open: visible, ...restProps, onOk: handleModalOk, onCancel: handleModalCancel }, content));
};
var modal_default = Modal;
